@@ -1,22 +1,21 @@
-# Original author : Fabian Jakobs
-# Author Pierre Schnizer
-"""
-   This chapter describes functions for creating and manipulating
+# Author : Fabian Jakobs, Pierre Schnizer
+# Date: 2003?, 2017
+"""Permutation
+
+This chapter describes functions for creating and manipulating
 permutations. A permutation p is represented by an array of n integers
-in the range 0 .. n-1, where each value p_i occurs once and only once.
-The application of a permutation p to a vector v yields a new vector v'
-where v'_i = v_{p_i}.  For example, the array (0,1,3,2) represents a
+in the range 0 .. n-1, where each value :math:`p_i` occurs once and only once.
+The application of a permutation p to a vector :math:`v` yields a new vector
+:math:`v'` where :math:`v'_i = v_{p_i}.`  For example, the array (0,1,3,2) represents a
 permutation which exchanges the last two elements of a four element
 vector.  The corresponding identity permutation is (0,1,2,3).
 """
 
 from . import gslwrap
 
-
 class Permutation(gslwrap.Permutation):
     def linear_to_canonical(self):
-        """
-        Computes the canonical form of the current permutation and returns it
+        """Computes the canonical form of the current permutation and returns it
         in a new permutation
         """
         q = Permutation(len(self))
@@ -24,8 +23,7 @@ class Permutation(gslwrap.Permutation):
         return q
     
     def canonical_to_linear(self):
-        """
-        Computes the linear form of the current permutation and returns it
+        """Computes the linear form of the current permutation and returns it
         in a new permutation
         """
         q = Permutation(len(self))
@@ -33,8 +31,7 @@ class Permutation(gslwrap.Permutation):
         return q
             
     def inverse(self):
-        """
-        Computes the inverse form of the current permutation and returns it
+        """Computes the inverse form of the current permutation and returns it
         in a new permutation.
         """
         inv = Permutation(len(self))
@@ -42,8 +39,7 @@ class Permutation(gslwrap.Permutation):
         return inv
 
     def mul(self, b):
-        """
-        Mutliplies this permutation with an other permutation and returns the
+        """Mutliplies this permutation with an other permutation and returns the
         result in a new permutation.
         """
 
