@@ -2,7 +2,7 @@
  * author: Pierre Schnizer
  * created: March 2004
  * file: pygsl/src/initmodule.c
- * $Id: initmodule.c,v 1.20 2016/04/02 08:23:30 schnizer Exp $
+ * $Id$
  *
  * Changes: 
  *     7. October 2003:
@@ -155,18 +155,104 @@ PyGSL_get_debug_level(PyObject *self, PyObject *args)
 
 static void * _PyGSL_API[PyGSL_NENTRIES_NUM];
 
+static const char pygsl_init_set_debug_level_doc[] =
+  "Set the internal debug level\n"
+  "\n"
+  "see :py:func:`pygsl.set_debug_level` for details\n";
+
+
+static const char pygsl_init_get_debug_level_doc[] =
+  "Get the internal debug level\n"
+  "\n"
+  "see :py:func:`pygsl.set_debug_level` for details\n";
+
+static const char reg_exc_doc[] =
+  "Used to register all exceptions\n"
+  "\n"
+  "WARNING:\n"
+  "    Internal function! Do not use it if not familar!";
+
+static const char reg_war_doc[] =
+  "Used to register all exceptions\n"
+  "\n"
+  "WARNING:\n"
+  "    Internal function! Do not use it if not familar!";
+
+static const char eh_state_reset_doc[] =
+  "Reset the stored error state\n"
+  "\n"
+  "User access best using: :py:data:`pygsl.errors.error_safe_state`\n";
+
+static const char eh_state_get_doc[] =
+  "Get the stored error state\n"
+  "\n"
+  "User access best using: :py:data:`pygsl.errors.error_safe_state`\n";
+
+static const char vector_tf_doc[] =
+  "Number of transforms required by vector objects\n"
+  "\n"
+  "How many times objects which were passed as vector arguments had to be\n"
+  "transformed to appropriate numpy array?\n"
+  "\n"
+  "Args:\n"
+  "     None"
+  "\n"
+  "Returns:\n"
+  "     long: number of convertions executed"
+  "\n";
+
+static const char matrix_tf_doc[] =
+  "Number of transforms required by matrix objects\n"
+  "\n"
+  "How many times objects which were passed as matrix arguments had to be\n"
+  "transformed to appropriate numpy array?\n"
+  "\n"
+  "Args:\n"
+  "     None"
+  "\n"
+  "Returns:\n"
+  "     long: number of convertions executed"
+  "\n";
+
+static const char complex_tf_doc[] =
+  "Number of transforms required by complex objects\n"
+  "\n"
+  "How many times objects which were passed as complex arguments had to be\n"
+  "transformed to appropriate python object?\n"
+  "\n"
+  "Args:\n"
+  "     None"
+  "\n"
+  "Returns:\n"
+  "     long: number of convertions executed"
+  "\n";
+
+static const char float_tf_doc[] =
+  "Number of transforms required by float objects\n"
+  "\n"
+  "How many times objects which were passed as float arguments had to be\n"
+  "transformed to appropriate object? (e.g. an integer had to be converted\n"
+  "to a float)\n"
+  "\n"
+  "Args:\n"
+  "     None"
+  "\n"
+  "Returns:\n"
+  "     long: number of convertions executed"
+  "\n";
+
 static PyMethodDef initMethods[] = {
-     {"get_debug_level", PyGSL_get_debug_level, METH_NOARGS, NULL},
-     {"set_debug_level", PyGSL_set_debug_level, METH_VARARGS, NULL},
-     {"vector_transform_counter",  PyGSL_get_vector_transform_counter ,METH_NOARGS, NULL},
-     {"matrix_transform_counter",  PyGSL_get_matrix_transform_counter ,METH_NOARGS, NULL},
-     {"complex_transform_counter", PyGSL_get_complex_transform_counter,METH_NOARGS, NULL},
-     {"float_transform_counter",   PyGSL_get_float_transform_counter  ,METH_NOARGS, NULL},
-     {"register_exceptions",       PyGSL_register_exceptions,          METH_VARARGS,NULL},
-     {"register_warnings",         PyGSL_register_warnings,            METH_VARARGS,NULL},
+     {"get_debug_level", PyGSL_get_debug_level, METH_NOARGS, pygsl_init_get_debug_level_doc},
+     {"set_debug_level", PyGSL_set_debug_level, METH_VARARGS, pygsl_init_set_debug_level_doc},
+     {"vector_transform_counter",  PyGSL_get_vector_transform_counter ,METH_NOARGS, vector_tf_doc},
+     {"matrix_transform_counter",  PyGSL_get_matrix_transform_counter ,METH_NOARGS, matrix_tf_doc},
+     {"complex_transform_counter", PyGSL_get_complex_transform_counter,METH_NOARGS, complex_tf_doc},
+     {"float_transform_counter",   PyGSL_get_float_transform_counter  ,METH_NOARGS, float_tf_doc},
+     {"register_exceptions",       PyGSL_register_exceptions,          METH_VARARGS, reg_exc_doc},
+     {"register_warnings",         PyGSL_register_warnings,            METH_VARARGS, reg_war_doc},
      {"add_c_traceback_frames",    PyGSL_add_c_traceback_frames,       METH_VARARGS,add_c_traceback_frames_doc},
-     {"error_handler_state_reset", PyGSL_pygsl_error_handler_save_reset, METH_NOARGS, NULL},
-     {"error_handler_state_get",   PyGSL_get_gsl_error_handler_saved_state, METH_NOARGS, NULL},
+     {"error_handler_state_reset", PyGSL_pygsl_error_handler_save_reset, METH_NOARGS, eh_state_reset_doc},
+     {"error_handler_state_get",   PyGSL_get_gsl_error_handler_saved_state, METH_NOARGS, eh_state_get_doc},
     {NULL,     NULL, 0, NULL}        /* Sentinel */
 };
 
@@ -223,11 +309,23 @@ PyGSL_init_api(void)
      _PyGSL_API[PyGSL_string_as_string_NUM                     ] = (void *) &_PyGSL_string_as_string                     ;
 }
 
+static const char pygsl_init_m_doc[] =
+  "pygsl.init module\n"
+"\n"
+"This module is a collection of internal conversion function. These functions\n"
+"typically need not be accessed by the pygsl user. All functionality is wrapped\n"
+"by appropriate functions and exported to the user at a higher level\n"
+"\n"
+"WARNING:\n"
+"    Please note the functions given here change the total behaviour of pygsl.\n"
+"    If wrongly used it could even crash the program.\n"
+"\n";
+  
 #ifdef PyGSL_PY3K
 static struct PyModuleDef moduledef = {
         PyModuleDef_HEAD_INIT,
         "pygsl.init",
-        NULL,
+        pygsl_init_m_doc,
         -1,
         initMethods,
         NULL,
