@@ -4,11 +4,11 @@
  *  Date   : 1. July. 2003
  *
  */
-
 #include <pygsl/error_helpers.h>
 #include <pygsl/block_helpers.h>
+#include <pygsl/string_helpers.h>
 #include <pygsl/utils.h>
-
+#include <pygsl/pygsl_features.h>
 #ifdef PyGSL_NO_IMPORT_API
 #undef PyGSL_NO_IMPORT_API
 #endif
@@ -21,7 +21,6 @@
  * All doc strings
  */
 static PyObject *module = NULL;
-
 #include "rng_helpers.c"
 #include "rngmodule_docs.h"
 
@@ -31,13 +30,145 @@ static PyObject * rng_call(PyGSL_rng *self, PyObject *args);
 
 #undef PyGSL_RNG_Check
 
-#define PyGSL_RNG_Check(op) ((op)->ob_type == &PyGSL_rng_pytype)
+#define PyGSL_RNG_Check(ob) (Py_TYPE(ob) == &PyGSL_rng_pytype)
 
-static PyObject *		/* on "instance.attr" */
-rng_getattr (PyGSL_rng *self, char *name);
+static void
+rng_delete(PyGSL_rng *self);
+
+static PyObject *	
+rng_call (PyGSL_rng *self, PyObject *args);
+static PyObject *
+rng_get(PyGSL_rng *self, PyObject *args);
+static PyObject *
+rng_set(PyGSL_rng *self, PyObject *args);
+static PyObject *
+rng_uniform_int (PyGSL_rng *self, PyObject *args);
+ static PyObject *
+rng_uniform_pos (PyGSL_rng *self, PyObject *args);
+
+static PyObject * rng_max(PyGSL_rng *self, PyObject *args);
+static PyObject * rng_min(PyGSL_rng *self, PyObject *args);
+static PyObject * rng_name(PyGSL_rng *self, PyObject *args);
+static PyObject * rng_clone(PyGSL_rng *self, PyObject *args);
+
+#define RNG_DISTRIBUTION(name, function)                                     \
+static PyObject* rng_ ## name (PyGSL_rng *self, PyObject *args);              
+#include "rng_distributions.h"
+#undef RNG_DISTRIBUTION
+
+/* Redefine to trigger emacs into correct coloring */
+/*
+ * This list is not optimized. I guess... Do you know how to optimize it?
+ */
+static struct PyMethodDef rng_methods[] = {
+  {"get", (PyCFunction) rng_get, METH_VARARGS, rng_get_doc},
+  {"set", (PyCFunction) rng_set, METH_VARARGS, rng_set_doc},
+  {"uniform", (PyCFunction) rng_call, METH_VARARGS, rng_uniform_doc},
+  {"uniform_pos", (PyCFunction) rng_uniform_pos, METH_VARARGS, rng_uniform_pos_doc},
+  {"uniform_int", (PyCFunction) rng_uniform_int, METH_VARARGS, rng_uniform_int_doc},
+  {"name", (PyCFunction) rng_name, METH_VARARGS, NULL},
+  {"max", (PyCFunction) rng_max, METH_VARARGS, rng_max_doc},
+  {"min", (PyCFunction) rng_min, METH_VARARGS, rng_min_doc},
+  {"clone", (PyCFunction) rng_clone, METH_VARARGS, rng_clone_doc},
+#if  (PY_MAJOR_VERSION == 2) && (PY_MINOR_VERSION == 3)
+  /* RNG clone can not be used to copy a rng type in python 2.3 No idea how to do that correctly */
+#else
+  {"__copy__", (PyCFunction) rng_clone, METH_VARARGS, rng_clone_doc},
+#endif
+  /* distributions */
+  {"gaussian", (PyCFunction) rng_gaussian,METH_VARARGS, rng_gaussian_doc},
+  {"gaussian_ratio_method", (PyCFunction) rng_gaussian_ratio_method,METH_VARARGS, rng_gaussian_ratio_doc},
+  {"ugaussian", (PyCFunction) rng_ugaussian,METH_VARARGS, rng_ugaussian_doc},
+  {"ugaussian_ratio_method",(PyCFunction) rng_ugaussian_ratio_method,METH_VARARGS, rng_ugaussian_ratio_doc},
+  {"gaussian_tail", (PyCFunction) rng_gaussian_tail,METH_VARARGS, rng_gaussian_tail_doc},
+  {"ugaussian_tail",(PyCFunction) rng_ugaussian_tail,METH_VARARGS, rng_ugaussian_tail_doc},
+  {"bivariate_gaussian", (PyCFunction) rng_bivariate_gaussian,METH_VARARGS, rng_bivariate_gaussian_doc},
+  {"exponential",(PyCFunction)rng_exponential,METH_VARARGS, rng_exponential_doc},
+  {"laplace",(PyCFunction)rng_laplace,METH_VARARGS, rng_laplace_doc},
+  {"exppow",(PyCFunction)rng_exppow,METH_VARARGS, rng_exppow_doc},
+  {"cauchy",(PyCFunction)rng_cauchy,METH_VARARGS, rng_cauchy_doc},
+  {"rayleigh",(PyCFunction)rng_rayleigh,METH_VARARGS, rng_rayleigh_doc},
+  {"rayleigh_tail",(PyCFunction)rng_rayleigh_tail,METH_VARARGS, rng_rayleigh_tail_doc},
+  {"levy",(PyCFunction)rng_levy,METH_VARARGS, rng_levy_doc},
+  {"levy_skew",(PyCFunction)rng_levy_skew,METH_VARARGS, rng_levy_skew_doc},
+  {"gamma",(PyCFunction)rng_gamma,METH_VARARGS, rng_gamma_doc},
+  {"gamma_int",(PyCFunction)rng_gamma_int,METH_VARARGS, NULL},
+  {"flat",(PyCFunction)rng_flat,METH_VARARGS, rng_flat_doc},
+  {"lognormal",(PyCFunction)rng_lognormal,METH_VARARGS, rng_lognormal_doc},
+  {"chisq",(PyCFunction)rng_chisq,METH_VARARGS, rng_chisq_doc},
+  {"fdist",(PyCFunction)rng_fdist,METH_VARARGS, rng_fdist_doc},
+  {"tdist",(PyCFunction)rng_tdist,METH_VARARGS, rng_tdist_doc},
+  {"beta",(PyCFunction)rng_beta,METH_VARARGS, rng_beta_doc},
+  {"logistic",(PyCFunction)rng_logistic,METH_VARARGS, rng_logistic_doc},
+  {"pareto",(PyCFunction)rng_pareto,METH_VARARGS, rng_pareto_doc},
+  {"dir_2d",(PyCFunction)rng_dir_2d,METH_VARARGS, rng_dir_2d_doc},
+  {"dir_2d_trig_method",(PyCFunction)rng_dir_2d_trig_method,METH_VARARGS, rng_dir_2d_trig_method_doc},
+  {"dir_3d",(PyCFunction)rng_dir_3d,METH_VARARGS, rng_dir_3d_doc},
+  {"dir_nd",(PyCFunction)rng_dir_nd,METH_VARARGS, rng_dir_nd_doc},
+  {"weibull",(PyCFunction)rng_weibull,METH_VARARGS, rng_weibull_doc},
+  {"gumbel1",(PyCFunction)rng_gumbel1,METH_VARARGS, rng_gumbel1_doc},
+  {"gumbel2",(PyCFunction)rng_gumbel2,METH_VARARGS, rng_gumbel2_doc},
+  {"poisson",(PyCFunction)rng_poisson,METH_VARARGS, rng_poisson_doc},
+  {"bernoulli",(PyCFunction)rng_bernoulli,METH_VARARGS, rng_bernoulli_doc},
+  {"binomial",(PyCFunction)rng_binomial,METH_VARARGS, rng_binomial_doc},
+  {"negative_binomial",(PyCFunction)rng_negative_binomial,METH_VARARGS, rng_negative_binomial_doc},
+  {"pascal",(PyCFunction)rng_pascal,METH_VARARGS, rng_pascal_doc},
+  {"geometric",(PyCFunction)rng_geometric,METH_VARARGS, rng_geometric_doc},
+  {"hypergeometric",(PyCFunction)rng_hypergeometric,METH_VARARGS, rng_hypergeometric_doc},
+  {"logarithmic",(PyCFunction)rng_logarithmic,METH_VARARGS, rng_logarithmic_doc},
+  {"landau",(PyCFunction)rng_landau,METH_VARARGS, rng_landau_doc},
+  {"erlang",(PyCFunction)rng_erlang,METH_VARARGS, NULL},  
+  {"multinomial",(PyCFunction)rng_multinomial,METH_VARARGS, multinomial_doc},
+  {"dirichlet",(PyCFunction)rng_dirichlet,METH_VARARGS, rng_dirichlet_doc},
+  {NULL, NULL}
+};
 
 
-PyTypeObject PyGSL_rng_pytype = {
+#ifdef PyGSL_PY3K
+static PyTypeObject PyGSL_rng_pytype = {
+	PyObject_HEAD_INIT(NULL)
+	"PyGSL_rng",                    /* tp_name */
+	sizeof(PyGSL_rng),              /* tp_basicsize */
+	0,                                          /* tp_itemsize */
+	(destructor) rng_delete, /* tp_dealloc */
+	0,                       /* tp_print */
+	0,                       /* tp_getattr */
+	0,                       /* tp_setattr */
+	0,                       /* tp_reserved */
+	0,                       /* tp_repr */
+	0,                       /* tp_as_number */
+	0,                       /* tp_as_sequence */
+	0,                       /* tp_as_mapping */
+	0,                       /* tp_hash */
+	(ternaryfunc)  rng_call, /* tp_call */
+	0,                       /* tp_str */
+	0,                       /* tp_getattro */
+	0,                       /* tp_setattro */
+	0,                       /* tp_as_buffer */
+	Py_TPFLAGS_DEFAULT,      /* tp_flags */
+	(char *)rng_type_doc, /* tp_doc */
+	0,                       /* tp_traverse */
+	0,                       /* tp_clear */
+	0,                       /* tp_richcompare */
+	0,                       /* tp_weaklistoffset */
+	0,                       /* tp_iter */
+	0,                       /* tp_iternext */
+	rng_methods,          /* tp_methods */
+	0,                       /* tp_members */
+	0,                       /* tp_getset */
+	0,                       /* tp_base */
+	0,                       /* tp_dict */
+	0,                       /* tp_descr_get */
+	0,                       /* tp_descr_set */
+	0,                       /* tp_dictoffset */
+	0,                       /* tp_init */
+	0,                       /* tp_alloc */
+	0,                       /* tp_new */
+};
+#else /* PyGSL_PY3K */
+static PyObject *
+rng_getattr(PyGSL_rng *self, char *name);
+static PyTypeObject PyGSL_rng_pytype = {
   PyObject_HEAD_INIT(NULL)	/* fix up the type slot in initcrng */
   0,				/* ob_size */
   "PyGSL_rng",			/* tp_name */
@@ -67,7 +198,7 @@ PyTypeObject PyGSL_rng_pytype = {
   0L,				/* tp_flags */
   rng_type_doc		/* tp_doc */
 };
-
+#endif /* PyGSL_PY3K */
 
 
 
@@ -166,6 +297,7 @@ rng_uniform_pos (PyGSL_rng *self, PyObject *args)
      return tmp;
 }
 
+
 static PyObject *
 rng_uniform_int (PyGSL_rng *self, PyObject *args)
 {
@@ -232,7 +364,7 @@ rng_name(PyGSL_rng *self, PyObject *args)
      assert(PyGSL_RNG_Check(self));
      if(0 == PyArg_ParseTuple(args, ":name"))
 	  return NULL;
-     tmp = PyString_FromString(gsl_rng_name(self->rng));
+     tmp = PyGSL_string_from_string(gsl_rng_name(self->rng));
      FUNC_MESS_END();
      return tmp;
 }
@@ -278,6 +410,7 @@ rng_clone(PyGSL_rng *self, PyObject *args)
      return (PyObject *) rng;
 }
 
+
 /*
  * Is #name a standard macro definition?
  */
@@ -297,73 +430,8 @@ static PyObject* rng_ ## name (PyGSL_rng *self, PyObject *args)              \
 
 #include "rng_distributions.h"
 
-/* Redefine to trigger emacs into correct coloring */
-/*
- * This list is not optimized. I guess... Do you know how to optimize it?
- */
-static struct PyMethodDef rng_methods[] = {
-  {"get", (PyCFunction) rng_get, METH_VARARGS, rng_get_doc},
-  {"set", (PyCFunction) rng_set, METH_VARARGS, rng_set_doc},
-  {"uniform", (PyCFunction) rng_call, METH_VARARGS, rng_uniform_doc},
-  {"uniform_pos", (PyCFunction) rng_uniform_pos, METH_VARARGS, rng_uniform_pos_doc},
-  {"uniform_int", (PyCFunction) rng_uniform_int, METH_VARARGS, rng_uniform_int_doc},
-  {"name", (PyCFunction) rng_name, METH_VARARGS, NULL},
-  {"max", (PyCFunction) rng_max, METH_VARARGS, rng_max_doc},
-  {"min", (PyCFunction) rng_min, METH_VARARGS, rng_min_doc},
-  {"clone", (PyCFunction) rng_clone, METH_VARARGS, rng_clone_doc},
-#if  (PY_MAJOR_VERSION == 2) && (PY_MINOR_VERSION == 3)
-  /* RNG clone can not be used to copy a rng type in python 2.3 No idea how to do that correctly */
-#else
-  {"__copy__", (PyCFunction) rng_clone, METH_VARARGS, rng_clone_doc},
-#endif
-  /* distributions */
-  {"gaussian", (PyCFunction) rng_gaussian,METH_VARARGS, rng_gaussian_doc},
-  {"gaussian_ratio_method", (PyCFunction) rng_gaussian_ratio_method,METH_VARARGS, rng_gaussian_ratio_doc},
-  {"ugaussian", (PyCFunction) rng_ugaussian,METH_VARARGS, rng_ugaussian_doc},
-  {"ugaussian_ratio_method",(PyCFunction) rng_ugaussian_ratio_method,METH_VARARGS, rng_ugaussian_ratio_doc},
-  {"gaussian_tail", (PyCFunction) rng_gaussian_tail,METH_VARARGS, rng_gaussian_tail_doc},
-  {"ugaussian_tail",(PyCFunction) rng_ugaussian_tail,METH_VARARGS, rng_ugaussian_tail_doc},
-  {"bivariate_gaussian", (PyCFunction) rng_bivariate_gaussian,METH_VARARGS, rng_bivariate_gaussian_doc},
-  {"exponential",(PyCFunction)rng_exponential,METH_VARARGS, rng_exponential_doc},
-  {"laplace",(PyCFunction)rng_laplace,METH_VARARGS, rng_laplace_doc},
-  {"exppow",(PyCFunction)rng_exppow,METH_VARARGS, rng_exppow_doc},
-  {"cauchy",(PyCFunction)rng_cauchy,METH_VARARGS, rng_cauchy_doc},
-  {"rayleigh",(PyCFunction)rng_rayleigh,METH_VARARGS, rng_rayleigh_doc},
-  {"rayleigh_tail",(PyCFunction)rng_rayleigh_tail,METH_VARARGS, rng_rayleigh_tail_doc},
-  {"levy",(PyCFunction)rng_levy,METH_VARARGS, rng_levy_doc},
-  {"levy_skew",(PyCFunction)rng_levy_skew,METH_VARARGS, rng_levy_skew_doc},
-  {"gamma",(PyCFunction)rng_gamma,METH_VARARGS, rng_gamma_doc},
-  {"gamma_int",(PyCFunction)rng_gamma_int,METH_VARARGS, NULL},
-  {"flat",(PyCFunction)rng_flat,METH_VARARGS, rng_flat_doc},
-  {"lognormal",(PyCFunction)rng_lognormal,METH_VARARGS, rng_lognormal_doc},
-  {"chisq",(PyCFunction)rng_chisq,METH_VARARGS, rng_chisq_doc},
-  {"fdist",(PyCFunction)rng_fdist,METH_VARARGS, rng_fdist_doc},
-  {"tdist",(PyCFunction)rng_tdist,METH_VARARGS, rng_tdist_doc},
-  {"beta",(PyCFunction)rng_beta,METH_VARARGS, rng_beta_doc},
-  {"logistic",(PyCFunction)rng_logistic,METH_VARARGS, rng_logistic_doc},
-  {"pareto",(PyCFunction)rng_pareto,METH_VARARGS, rng_pareto_doc},
-  {"dir_2d",(PyCFunction)rng_dir_2d,METH_VARARGS, rng_dir_2d_doc},
-  {"dir_2d_trig_method",(PyCFunction)rng_dir_2d_trig_method,METH_VARARGS, rng_dir_2d_trig_method_doc},
-  {"dir_3d",(PyCFunction)rng_dir_3d,METH_VARARGS, rng_dir_3d_doc},
-  {"dir_nd",(PyCFunction)rng_dir_nd,METH_VARARGS, rng_dir_nd_doc},
-  {"weibull",(PyCFunction)rng_weibull,METH_VARARGS, rng_weibull_doc},
-  {"gumbel1",(PyCFunction)rng_gumbel1,METH_VARARGS, rng_gumbel1_doc},
-  {"gumbel2",(PyCFunction)rng_gumbel2,METH_VARARGS, rng_gumbel2_doc},
-  {"poisson",(PyCFunction)rng_poisson,METH_VARARGS, rng_poisson_doc},
-  {"bernoulli",(PyCFunction)rng_bernoulli,METH_VARARGS, rng_bernoulli_doc},
-  {"binomial",(PyCFunction)rng_binomial,METH_VARARGS, rng_binomial_doc},
-  {"negative_binomial",(PyCFunction)rng_negative_binomial,METH_VARARGS, rng_negative_binomial_doc},
-  {"pascal",(PyCFunction)rng_pascal,METH_VARARGS, rng_pascal_doc},
-  {"geometric",(PyCFunction)rng_geometric,METH_VARARGS, rng_geometric_doc},
-  {"hypergeometric",(PyCFunction)rng_hypergeometric,METH_VARARGS, rng_hypergeometric_doc},
-  {"logarithmic",(PyCFunction)rng_logarithmic,METH_VARARGS, rng_logarithmic_doc},
-  {"landau",(PyCFunction)rng_landau,METH_VARARGS, rng_landau_doc},
-  {"erlang",(PyCFunction)rng_erlang,METH_VARARGS, NULL},  
-  {"multinomial",(PyCFunction)rng_multinomial,METH_VARARGS, multinomial_doc},
-  {"dirichlet",(PyCFunction)rng_dirichlet,METH_VARARGS, rng_dirichlet_doc},
-  {NULL, NULL,}
-};
 
+#ifndef PyGSL_PY3K
 static PyObject *
 rng_getattr(PyGSL_rng *self, char *name)
 {
@@ -380,25 +448,43 @@ rng_getattr(PyGSL_rng *self, char *name)
      return tmp;
 }
 
+#endif /* PyGSL_PY3K */
 
+
+
+
+#define BUF_LEN 256
 static PyObject *
 rng_create_list(PyObject *self, PyObject *args)
 {
      const gsl_rng_type** thisRNGType=gsl_rng_types_setup();
      PyObject* list = NULL, *item=NULL;
-     
+     char buffer[BUF_LEN], *tmp;
+     int size;
      FUNC_MESS_BEGIN();
      /* provide other rng types as subclasses of rng */
 
      list = PyList_New(0);
      while ((*thisRNGType)!=NULL) {
-	  item = PyString_FromString((*thisRNGType)->name);
-	  Py_INCREF(item);
-	  assert(item);
-	  PyGSL_clear_name(PyString_AsString(item), PyString_Size(item));
-	  if(PyList_Append(list, item) != 0)
-	       goto fail;
-	  thisRNGType++;
+	     tmp = (char *) ((*thisRNGType)->name);
+	     size = strlen(tmp);
+	     if(size > BUF_LEN - 1){
+		     pygsl_error("tmp buffer to small for clearing the name",
+				 __FILE__, __LINE__, GSL_ESANITY);
+	     }
+	     strcpy(buffer, tmp);
+	     PyGSL_clear_name(buffer, size);
+
+	     item = PyGSL_string_from_string(tmp);
+	     if(item == NULL)
+		     goto fail;
+	  
+	     Py_INCREF(item);
+	     assert(item);
+	     
+	     if(PyList_Append(list, item) != 0)
+		     goto fail;
+	     thisRNGType++;
      }
      FUNC_MESS_END();
      return list;
@@ -585,13 +671,46 @@ set_api_pointer(void)
      FUNC_MESS_END();
 }
 
-void 
-initrng(void)
+
+#ifdef PyGSL_PY3K
+static struct PyModuleDef moduledef = {
+        PyModuleDef_HEAD_INIT,
+        "pygsl.rng",
+        NULL,
+        -1,
+	PyGSL_rng_module_functions,
+        NULL,
+        NULL,
+        NULL,
+        NULL
+};
+#endif /* PyGSL_PY3K */
+
+#ifdef __cplusplus
+extern "C"
+#endif
+
+
+#ifdef PyGSL_PY3K
+PyObject *PyInit_rng(void)
+#define RETVAL m
+#else /* PyGSL_PY3K */
+DL_EXPORT(void) initrng(void)
+#define RETVAL
+#endif /* PyGSL_PY3K */
 {
      PyObject *m=NULL, *item=NULL, *dict=NULL;
      PyObject *api=NULL;
 
-     m = Py_InitModule("rng", PyGSL_rng_module_functions);
+#ifdef PyGSL_PY3K
+	m = PyModule_Create(&moduledef);
+#else /* PyGSL_PY3K */
+	m = Py_InitModule("rng", PyGSL_rng_module_functions);
+#endif /* PyGSL_PY3K */
+
+	if(m == NULL)
+	  return RETVAL;
+	
      assert(m);
      /* import_array(); */
      init_pygsl();
@@ -603,7 +722,7 @@ initrng(void)
      if(!dict)
 	  goto fail;
      
-     if (!(item = PyString_FromString(rng_module_doc))){
+     if (!(item = PyGSL_string_from_string(rng_module_doc))){
 	  PyErr_SetString(PyExc_ImportError, 
 			  "I could not generate module doc string!");
 	  goto fail;
@@ -614,11 +733,19 @@ initrng(void)
 	  goto fail;
      }
 
+#ifdef PyGSL_PY3K
+	if (PyType_Ready(&PyGSL_rng_pytype) < 0)
+		return NULL;
+#else /* PyGSL_PY3K */
      PyGSL_rng_pytype.ob_type = &PyType_Type;
+#endif /* PyGSL_PY3K */
 
 
      set_api_pointer();
-     api = PyCObject_FromVoidPtr((void *) PyGSL_API, NULL);
+     api = PyCapsule_New((void *) PyGSL_API, _PyGSL_RNG_API_CAP, NULL);
+     if(api == NULL)
+       goto fail;
+     
      assert(api);
      if (PyDict_SetItemString(dict, "_PYGSL_RNG_API", api) != 0){
 	  PyErr_SetString(PyExc_ImportError, 
@@ -626,11 +753,11 @@ initrng(void)
 	  goto fail;
      }
      
-     return;
+     return RETVAL;
      
  fail:
      if(!PyErr_Occurred()){
 	  PyErr_SetString(PyExc_ImportError, "I could not init rng module!");
      }
-
+     return RETVAL;
 }
