@@ -20,6 +20,7 @@
 #ifndef _PyGSL_UFUNC_SUPPORTED
 #error "UFUNCs not supported by the selected/found array module!"
 #endif
+#include <pygsl/block_helpers.h>
 /*
    #include <pygsl/utils.h>
    #include <pygsl/error_helpers.h>
@@ -35,6 +36,9 @@ static inline int
 _pygsl_sf_long_to_int(long val, int * result)
 {
 	int status = GSL_EFAILED;
+	
+	FUNC_MESS_BEGIN();
+
 	if (val > (long) INT_MAX){
 		status = GSL_EINVAL;
 		*result = INT_MAX;
@@ -45,24 +49,42 @@ _pygsl_sf_long_to_int(long val, int * result)
 		status = GSL_SUCCESS;
 		*result = (int) val;
 	}
+
+	FUNC_MESS_END();
+	
 	return status;
 }
 
 static inline int
 _pygsl_sf_long_to_unsigned_int(long val, unsigned int * result)
 {
-	int status = GSL_EFAILED;
 
-	if (val > (long) UINT_MAX){
-		status = GSL_EINVAL;
-		*result = UINT_MAX;
-	} else if (val < 0){
+        int status = GSL_EFAILED;
+
+	FUNC_MESS_BEGIN();
+
+	DEBUG_MESS(2, "l-> ui: input %ld", val);
+	DEBUG_MESS(8, "sizeof(unsigned int) = %d sizeof(long) =%d", sizeof(unsigned int), sizeof(long));
+	DEBUG_MESS(8, "UINT_MAX = %u ", UINT_MAX, sizeof(unsigned int), sizeof(long));
+	
+	if (val < 0){
 		status = GSL_EINVAL;
 		*result = 0;
-	} else {
+		DEBUG_MESS(2, "Conversion long-> unsigned int: val %ld < 0", (val));
+	}
+        /* on windows long and int are 4 bytes .... so ignorable here ... */
+	else if ((UINT_MAX <  LONG_MAX) && (val > (long) UINT_MAX)){
+		status = GSL_EINVAL;
+		*result = UINT_MAX;
+		DEBUG_MESS(2, "Conversion long-> unsigned int: val %ld > UNIT_MAX = %ld ", val, UINT_MAX);
+	}
+	else {
 		status = GSL_SUCCESS;
 		*result = (int) val;
+		DEBUG_MESS(2, "Conversion long-> unsigned int: val %ld -> %u", val, *result);
 	}
+
+	FUNC_MESS_END();
 	return status;
 }
 
@@ -132,7 +154,7 @@ void  PyGSL_sf_ufunc_qi_dd_D_as_ff_F(char **args, int *dimensions, int *steps, v
         }
 	FUNC_MESS_END();
 }
-static PyUFuncGenericFunction PyGSL_sf_ufunc_qi_dd_D_one_data[] = {PyGSL_sf_ufunc_qi_dd_D_as_ff_F, PyGSL_sf_ufunc_qi_dd_D};
+static PyUFuncGenericFunction PyGSL_sf_ufunc_qi_dd_D_one_data[] = {(PyUFuncGenericFunction) PyGSL_sf_ufunc_qi_dd_D_as_ff_F, (PyUFuncGenericFunction) PyGSL_sf_ufunc_qi_dd_D};
 
 typedef int PyGSL_sf_ufunc_qi_D_dd_one(double, double, gsl_sf_result *, gsl_sf_result *);
 void  PyGSL_sf_ufunc_qi_D_dd(char **args, int *dimensions, int *steps, void *func)
@@ -175,7 +197,7 @@ void  PyGSL_sf_ufunc_qi_D_dd_as_F_ff(char **args, int *dimensions, int *steps, v
 	}
 	FUNC_MESS_END();
 }
-static PyUFuncGenericFunction PyGSL_sf_ufunc_qi_D_dd_one_data[] = {PyGSL_sf_ufunc_qi_D_dd_as_F_ff, PyGSL_sf_ufunc_qi_D_dd};
+static PyUFuncGenericFunction PyGSL_sf_ufunc_qi_D_dd_one_data[] = {(PyUFuncGenericFunction) PyGSL_sf_ufunc_qi_D_dd_as_F_ff, (PyUFuncGenericFunction) PyGSL_sf_ufunc_qi_D_dd};
 
 
 static char *PyGSL_polar_to_rect_doc = "Convert r, theta into a complex representation";
